# GE-Core
[![Open Source Love](https://badges.frapsoft.com/os/v1/open-source.png?v=103)](https://github.com/ellerbrock/open-source-badges/)
[![semantic-release](https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg)](https://github.com/semantic-release/semantic-release)
![PyPI - License](https://img.shields.io/pypi/l/ge-core)
[![PyPI Supported Python Versions](https://img.shields.io/pypi/pyversions/ge-core)](https://pypi.python.org/pypi/ge-core/)

[![GitHub Actions (master)](https://github.com/StjerneIdioten/GE-Core/actions/workflows/master.yml/badge.svg)](https://github.com/StjerneIdioten/GE-Core)
[![GitHub Actions (develop)](https://github.com/StjerneIdioten/GE-Core/actions/workflows/develop.yml/badge.svg)](https://github.com/StjerneIdioten/GE-Core)

<p align="left">
  <a href="https://www.buymeacoffee.com/StjerneIdioten">Support Me</a> •
  <a href="https://www.pypi.org/project/ge-core/">PyPI Package</a> •
</p>

## Description
This project has been launched as a rework of the [Blender I3D Addon](https://github.com/StjerneIdioten/I3D-Blender-Addon) into a separate standalone python package for working with modding of Giants Engine games, which can then be incorporated into specific projects such as an addon integration for Blender or any other tool. 

To begin with it will focus on interactions with I3D files, both importing and exporting, through an interface which can be implemented to work with anything that runs python

_This project is still in early development!_
